@@ -1,5 +1,3 @@
-from pathlib import Path
-
 try:
     from django import VERSION as _django_version
 
@@ -7,5 +5,3 @@ try:
         default_app_config = 'modeltranslation.apps.ModeltranslationConfig'
 except ImportError:
     pass
-
-__version__ = (Path(__file__).parent.parent / "VERSION").read_text().strip()
