@@ -12,7 +12,7 @@ def register(model_or_iterable, **options):
     class AuthorTranslation(TranslationOptions):
         pass
     """
-    from modeltranslation.translator import translator, TranslationOptions
+    from modeltranslation.translator import TranslationOptions, translator
 
     def wrapper(opts_class):
         if not issubclass(opts_class, TranslationOptions):
