@@ -1,12 +1,10 @@
-# -*- coding: utf-8 -*-
-from django.db.models import F, Q
 from django.core.management.base import BaseCommand, CommandError
+from django.db.models import F, ManyToManyField, Q
 
 from modeltranslation.settings import AVAILABLE_LANGUAGES, DEFAULT_LANGUAGE
 from modeltranslation.translator import translator
 from modeltranslation.utils import build_localized_fieldname
 
-
 COMMASPACE = ", "
 
 
@@ -83,8 +81,19 @@ class Command(BaseCommand):
                 def_lang_fieldname = build_localized_fieldname(field_name, lang)
 
                 # We'll only update fields which do not have an existing value
-                q = Q(**{def_lang_fieldname: None})
+                q = Q(**{f"{def_lang_fieldname}__isnull": True})
                 field = model._meta.get_field(field_name)
+                if isinstance(field, ManyToManyField):
+                    trans_field = getattr(model, def_lang_fieldname)
+                    if not trans_field.through.objects.exists():
+                        field_names = [f.name for f in trans_field.through._meta.fields]
+                        trans_field.through.objects.bulk_create(
+                            trans_field.through(
+                                **{f: v for f, v in dict(inst.__dict__) if f in field_names}
+                            )
+                            for inst in getattr(model, field_name).through.objects.all()
+                        )
+                    continue
                 if field.empty_strings_allowed:
                     q |= Q(**{def_lang_fieldname: ""})
 
