@@ -1,4 +1,5 @@
-from modeltranslation.translator import translator, TranslationOptions
+from modeltranslation.translator import TranslationOptions, translator
+
 from .test_app.models import Other
 
 
